Django admin extensions - Django admin extensions

Skip to content

# Django admin extensions

## Installation

    pip install preusx-django-admin-extensions

Default admin panel consists of several own packages and dependencies. They may be used separately except `pxd_admin_extensions.contrib.all` which is the aggregator-package for all extensions.

    INSTALLED_APPS = [
      'pxd_admin_extensions.contrib.all',
      'pxd_admin_extensions.contrib.jet',
      'pxd_admin_extensions.contrib.stats',
      'pxd_admin_extensions.contrib.rangefilter',
      'pxd_admin_extensions',

      'django_better_admin_arrayfield',
      'admin_totals',
      'admin_numeric_filter',
      'jet.dashboard',
      'jet',
    ] + INSTALLED_APPS

After installation it's easy to use:

    from pxd_admin_extensions.contrib.all import AllAdmin
    ...

    @admin.register(SomeModel)
    class SomeModelAdmin(AllAdmin):
      pass

Project has a simple `example` app for a demonstration purposes.